import { __extends } from "tslib";
import React from 'react';
import { addErrorMessage } from 'app/actionCreators/indicator';
import Link from 'app/components/links/link';
import { t, tct } from 'app/locale';
import SettingsPageHeader from 'app/views/settings/components/settingsPageHeader';
import JsonForm from 'app/views/settings/components/forms/jsonForm';
import Form from 'app/views/settings/components/forms/form';
import { fields } from 'app/data/forms/projectGeneralSettings';
import AsyncView from 'app/views/asyncView';
import ProjectActions from 'app/actions/projectActions';
import withProject from 'app/utils/withProject';
import DataScrubbing from '../components/dataScrubbing';
var ProjectSecurityAndPrivacy = /** @class */ (function (_super) {
    __extends(ProjectSecurityAndPrivacy, _super);
    function ProjectSecurityAndPrivacy() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.handleUpdateProject = function (data) {
            // This will update our project global state
            ProjectActions.updateSuccess(data);
        };
        return _this;
    }
    ProjectSecurityAndPrivacy.prototype.renderBody = function () {
        var _a = this.props, organization = _a.organization, project = _a.project;
        var initialData = project;
        var endpoint = "/projects/" + organization.slug + "/" + project.slug + "/";
        var access = new Set(organization.access);
        var features = new Set(organization.features);
        var relayPiiConfig = project.relayPiiConfig;
        var apiMethod = 'PUT';
        return (<React.Fragment>
        <SettingsPageHeader title={t('Security & Privacy')}/>
        <Form saveOnBlur allowUndo initialData={initialData} apiMethod={apiMethod} apiEndpoint={endpoint} onSubmitSuccess={this.handleUpdateProject} onSubmitError={function () { return addErrorMessage('Unable to save change'); }}>
          <JsonForm title={t('Security & Privacy')} additionalFieldProps={{
            organization: organization,
        }} features={features} disabled={!access.has('project:write')} fields={[fields.storeCrashReports]}/>
          <JsonForm title={t('Data Scrubbing')} additionalFieldProps={{
            organization: organization,
        }} features={features} disabled={!access.has('project:write')} fields={[
            fields.dataScrubber,
            fields.dataScrubberDefaults,
            fields.scrubIPAddresses,
            fields.sensitiveFields,
            fields.safeFields,
        ]}/>
        </Form>
        <DataScrubbing additionalContext={<span>
              {tct('These rules can be configured at the organization level in [linkToOrganizationSecurityAndPrivacy].', {
            linkToOrganizationSecurityAndPrivacy: (<Link to={"/settings/" + organization.slug + "/security-and-privacy/"}>
                      {t('Security and Privacy')}
                    </Link>),
        })}
            </span>} endpoint={endpoint} relayPiiConfig={relayPiiConfig} disabled={!access.has('project:write')} organization={organization} projectId={project.id} onSubmitSuccess={this.handleUpdateProject}/>
      </React.Fragment>);
    };
    return ProjectSecurityAndPrivacy;
}(AsyncView));
export default withProject(ProjectSecurityAndPrivacy);
//# sourceMappingURL=index.jsx.map